@@ -1,12 +1,12 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '1.69'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '1.70'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+#use Log::Any '$log';
 
 our %SPEC;
 
@@ -98,7 +98,7 @@ sub read_config {
         my $path           = $paths->[$i];
         my $filename = $path; $filename =~ s!.*[/\\]!!;
         my $wanted_section = $section_config_filename_map{$filename};
-        $log->tracef("[pericmd] Reading config file '%s' ...", $path);
+        #$log->tracef("[pericmd] Reading config file '%s' ...", $path);
         my $j = 0;
         $section_read_order{GLOBAL} = [$i, $j++];
         my $hoh = $reader->read_file(
@@ -190,18 +190,18 @@ sub get_args_from_config {
         # the matching subcommand
         if (length $scn) {
             if (length($sect_scn) && $sect_scn ne $scn) {
-                $log->tracef(
-                    "[pericmd] Skipped config section '%s' (%s)",
-                    $section0, "subcommand does not match '$scn'",
-                );
+                #$log->tracef(
+                #    "[pericmd] Skipped config section '%s' (%s)",
+                #    $section0, "subcommand does not match '$scn'",
+                #);
                 next;
             }
         } else {
             if (length $sect_scn) {
-                $log->tracef(
-                    "[pericmd] Skipped config section '%s' (%s)",
-                    $section0, "only for a certain subcommand",
-                );
+                #$log->tracef(
+                #    "[pericmd] Skipped config section '%s' (%s)",
+                #    $section0, "only for a certain subcommand",
+                #);
                 next;
             }
         }
@@ -210,19 +210,19 @@ sub get_args_from_config {
         # matching profile
         if (defined $profile) {
             if (defined($sect_profile) && $sect_profile ne $profile) {
-                $log->tracef(
-                    "[pericmd] Skipped config section '%s' (%s)",
-                    $section0, "profile does not match '$profile'",
-                );
+                #$log->tracef(
+                #    "[pericmd] Skipped config section '%s' (%s)",
+                #    $section0, "profile does not match '$profile'",
+                #);
                 next;
             }
             $found = 1 if defined($sect_profile) && $sect_profile eq $profile;
         } else {
             if (defined($sect_profile)) {
-                $log->tracef(
-                    "[pericmd] Skipped config section '%s' (%s)",
-                    $section0, "only for a certain profile",
-                );
+                #$log->tracef(
+                #    "[pericmd] Skipped config section '%s' (%s)",
+                #    $section0, "only for a certain profile",
+                #);
                 next;
             }
         }
@@ -230,10 +230,10 @@ sub get_args_from_config {
         # only use section marked with program=... if the program name matches
         if (defined($progn) && defined($keyvals{program})) {
             if ($progn ne $keyvals{program}) {
-                $log->tracef(
-                    "[pericmd] Skipped config section '%s' (%s)",
-                    $section0, "program does not match '$progn'",
-                );
+                #$log->tracef(
+                #    "[pericmd] Skipped config section '%s' (%s)",
+                #    $section0, "program does not match '$progn'",
+                #);
                 next;
             }
         }
@@ -243,43 +243,43 @@ sub get_args_from_config {
             my ($var, $val);
             if (($var, $val) = $env =~ /\A(\w+)=(.*)\z/) {
                 if (($ENV{$var} // '') ne $val) {
-                    $log->tracef(
-                        "[pericmd] Skipped config section '%s' (%s)",
-                        $section0, "env $var has non-matching value '".
-                            ($ENV{$var} // '')."'",
-                    );
+                    #$log->tracef(
+                    #    "[pericmd] Skipped config section '%s' (%s)",
+                    #    $section0, "env $var has non-matching value '".
+                    #        ($ENV{$var} // '')."'",
+                    #);
                     next;
                 }
             } elsif (($var, $val) = $env =~ /\A(\w+)!=(.*)\z/) {
                 if (($ENV{$var} // '') eq $val) {
-                    $log->tracef(
-                        "[pericmd] Skipped config section '%s' (%s)",
-                        $section0, "env $var has that value",
-                    );
+                    #$log->tracef(
+                    #    "[pericmd] Skipped config section '%s' (%s)",
+                    #    $section0, "env $var has that value",
+                    #);
                     next;
                 }
             } elsif (($var, $val) = $env =~ /\A(\w+)\*=(.*)\z/) {
                 if (index(($ENV{$var} // ''), $val) < 0) {
-                    $log->tracef(
-                        "[pericmd] Skipped config section '%s' (%s)",
-                        $section0, "env $var has value '".
-                            ($ENV{$var} // '')."' which does not contain the ".
-                                "requested string"
-                    );
+                    #$log->tracef(
+                    #    "[pericmd] Skipped config section '%s' (%s)",
+                    #    $section0, "env $var has value '".
+                    #        ($ENV{$var} // '')."' which does not contain the ".
+                    #            "requested string"
+                    #);
                     next;
                 }
             } else {
                 if (!$ENV{$env}) {
-                    $log->tracef(
-                        "[pericmd] Skipped config section '%s' (%s)",
-                        $section0, "env $env is not set/true",
-                    );
+                    #$log->tracef(
+                    #    "[pericmd] Skipped config section '%s' (%s)",
+                    #    $section0, "env $env is not set/true",
+                    #);
                     next;
                 }
             }
         }
 
-        $log->tracef("[pericmd] Reading config section '%s'", $section0);
+        #$log->tracef("[pericmd] Reading config section '%s'", $section0);
 
         my $as = $meta->{args} // {};
         for my $k (keys %{ $conf->{$section0} }) {
@@ -336,7 +336,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.69 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Util-Config), released on 2017-01-04.
+This document describes version 1.70 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Util-Config), released on 2017-01-12.
 
 =head1 FUNCTIONS
 
